USE [AdventureWorksDW2008]
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO

/****** Object:  UserDefinedTableType [dbo].[TerritoryType]    Script Date: 04/11/2008 20:59:10 ******/
CREATE TYPE [dbo].[TerritoryType] AS TABLE(
	[TerritoryKey] [int] NOT NULL,
	[TerritoryName] [nvarchar](50) NOT NULL
)
GO

/****** Object:  StoredProcedure [dbo].[uspGetSalesByTerritory]    Script Date: 04/11/2008 20:59:46 ******/
CREATE PROCEDURE [dbo].[uspGetSalesByTerritory] 
(
	@CalendarYear int, 
	@Territory TerritoryType READONLY
)
AS
BEGIN
	-- SET NOCOUNT ON added to prevent extra result sets from
	-- interfering with SELECT statements.
	SET NOCOUNT ON;

	SELECT      ST.SalesTerritoryGroup AS TerritoryGroup, D.FullDateAlternateKey AS [Date], SUM(FRS.SalesAmount) AS ResellerSalesAmount
FROM            DimDate AS D INNER JOIN
                         FactResellerSales AS FRS ON D.DateKey = FRS.OrderDateKey INNER JOIN
                         DimSalesTerritory AS ST ON FRS.SalesTerritoryKey = ST.SalesTerritoryKey INNER JOIN
                         @Territory AS T ON ST.SalesTerritoryKey = T.TerritoryKey
WHERE        (D.CalendarYear = @CalendarYear)
GROUP BY ST.SalesTerritoryGroup, D.FullDateAlternateKey
END

GO

/* Sample code to test the stored procedure */
DECLARE @CalendarYear int = 2004
DECLARE @Territory TerritoryType
insert into @Territory values (1, 'North America')
insert into @Territory values (9, 'Pacific')
EXECUTE [dbo].[uspGetSalesByTerritory] @CalendarYear,@Territory
GO
;


