﻿using System;
using System.Collections.Generic;
using System.Globalization;
using System.Text;
using System.Management;
using System.Diagnostics;

namespace WMI
{
    class Program
    {
        private const string _wmiNamespace      = @"\\{0}\root\Microsoft\SqlServer\ReportServer\RS_{1}\v10";
        private const string _wmiAdminNamespace = @"\\{0}\root\Microsoft\SqlServer\ReportServer\RS_{1}\v10\Admin";


        static void Main(string[] args)
        {
            string machineName = "localhost";
            string instanceName = "MSSQLSERVER";

            if (args.Length > 0)
            {
                machineName = args[0];
                if (args.Length == 2) instanceName = args[1];
            }
            GetReportServerUrl(machineName, instanceName);
            GetAdminSettings(machineName, instanceName);
        }

        internal static void GetReportServerUrl(string machineName, string instanceName)
        {
            string reportServerVirtualDirectory = String.Empty;
            string fullWmiNamespace = string.Format(_wmiNamespace, machineName, instanceName);

            ManagementScope scope = null;
            ConnectionOptions connOptions = new ConnectionOptions();

            //Get management scope
            try
            {
                scope = new ManagementScope(fullWmiNamespace, connOptions);
                scope.Connect();

                //Get management class
                ManagementPath path = new ManagementPath("MSReportServer_Instance");
                ObjectGetOptions options = new ObjectGetOptions();
                ManagementClass serverClass = new ManagementClass(scope, path, options);

                serverClass.Get();

                if (serverClass == null)
                    throw new Exception(string.Format(CultureInfo.InvariantCulture, "No WMI class found."));

                //Get instances
                ManagementObjectCollection instances = serverClass.GetInstances();
                Console.WriteLine("Instance Info ...");
                foreach (ManagementObject instance in instances)
                {
                    instance.Get();
                    foreach(PropertyData p in instance.Properties) Console.WriteLine (p.Name + ": " + p.Value);
                    ManagementBaseObject outParams = (ManagementBaseObject)instance.InvokeMethod("GetReportServerUrls", null, null);

                    string[] appNames = (string[])outParams["ApplicationName"];
                    string[] urls = (string[])outParams["URLs"];
                    for (int i = 0; i < appNames.Length; i++)  Console.WriteLine (appNames[i] + ": " + urls[i]);
                }
            }
            catch (Exception ex)
            {
                throw new Exception(string.Format(CultureInfo.InvariantCulture,
                    "An error occurred while attempting to get the ReportServer Url. " + ex.Message), ex);
            }

        }

        internal static void GetAdminSettings(string machineName, string instanceName)
        {
            const string WmiRSClass = "MSReportServer_ConfigurationSetting";
            ManagementClass serverClass;
            ManagementScope scope = new ManagementScope(String.Format(_wmiAdminNamespace, machineName, instanceName), null);

            // Connect to the Reporting Services namespace.\
            scope.Connect();
            ManagementPath path = new ManagementPath(WmiRSClass);
            serverClass = new ManagementClass(scope, path, null);

            // Connect to the management object.
            serverClass.Get();
            if (serverClass == null) throw new Exception("No class found");

            // Loop through the instances of the server class.
            ManagementObjectCollection instances = serverClass.GetInstances();

            Console.WriteLine();
            Console.WriteLine("Admin settings ...");
            foreach (ManagementObject instance in instances)
            {
                Console.Out.WriteLine("Instance {0}", instance["InstanceName"]);
                PropertyDataCollection instProps = instance.Properties;
                foreach (PropertyData prop in instProps)
                {
                    string name = prop.Name;
                    object val = prop.Value;
                    Console.Out.Write("Property Name: " + name);
                    if (val != null)
                        Console.Out.WriteLine("     Value: " + val.ToString());
                    else
                        Console.Out.WriteLine("     Value: <null>");
                }
            }
            Console.WriteLine("\n--- Press any key ---");
            Console.ReadKey();

        }
    }
}
