﻿using System;
using System.IO;
using System.IO.IsolatedStorage;
using System.Web.Services.Protocols;
using System.Windows.Forms;
using System.Reflection;


namespace IntegrationOptions
{
    /// <summary>
    /// Summary description for Util.
    /// </summary>
    public class Util
    {
        public Util()
        {
            //
            // TODO: Add constructor logic here
            //
        }
        /// <summary>
        /// Gets the isolated storage stream where the user settings are persisted
        /// </summary>
        /// <param name="path">Path to the isolated storage</param>
        /// <param name="m">File Mode</param>
        /// <param name="a">File Access</param>
        /// <param name="s">File Share</param>
        /// <returns></returns>
        internal static Stream GetSettingsStream(string path, FileMode m, FileAccess a, FileShare s)
        {
            return new IsolatedStorageFileStream(path, m, a, s,
                IsolatedStorageFile.GetUserStoreForAssembly());
        }

        /// <summary>
        /// Simple wrappers on top of Show Message to display errors
        /// </summary>
        /// <param name="ex"></param>
        internal static void ShowErrorMessage(System.Exception ex)
        {
            ShowErrorMessage(String.Empty, ex);
        }
        internal static void ShowErrorMessage(string messageText)
        {
            ShowErrorMessage(messageText, null);
        }
        internal static void ShowErrorMessage(string messageText, System.Exception ex)
        {
            if (ex != null)
            {
                if (ex is SoapException)
                {
                    switch (((SoapException)ex).Detail["ErrorCode"].InnerText)
                    {
                        case "rsReportParameterValueNotSet":
                            messageText += "\n" + "The report parameters do not match."; break;
                        case "rsItemNotFound":
                            messageText += "\n" + "Wrong report or report path. Please check the reportFolder element in the application configuration file."; break;
                    }
                    messageText += "\n" + "Exception Trace:\n" + ((SoapException)ex).Detail.InnerXml;
                }

                if (ex is System.Net.WebException)
                {
                    messageText += "\n" + "Cannot communicate with the Report Server. Please check the reportServer element in the application configuration file.";
                    messageText += "\n" + "Exception Trace:\n" + ex.ToString();
                }

            }
            MessageBox.Show(messageText, Assembly.GetExecutingAssembly().GetName().Name, MessageBoxButtons.OK, MessageBoxIcon.Error);
        }
        internal static string GetFileForReport(string reportPath, string format)
        {
            string fileName = Path.GetFileName(reportPath);
            string fileExt = null;

            switch (format.ToLower())
            {
                case "html4.0"  : fileExt = "html"; break;
                case "html3.2"  : fileExt = "html"; break;
                case "mhtml"    : fileExt = "mhtml"; break;
                case "excel"    : fileExt = "xls"; break;
                case "jpeg"     : fileExt = "jpg"; break;
                case "tiff"     : fileExt = "tif"; break;
                case "image"    : fileExt = "tif"; break;
                case "word"     : fileExt = "doc"; break;
                default         : fileExt = format; break;
            }

            fileName = fileName + "." + fileExt;
            return Application.UserAppDataPath + Path.DirectorySeparatorChar + fileName;
        }


    }
}
