﻿using System;
using System.Collections.Generic;
using System.Text;
using System.IO;
using System.Web.Services.Protocols;
using WebServiceDemo.ReportExecution;
using System.Net;

namespace WebServiceDemo
{
    class Program
    {
        static void Main(string[] args)
        {
            string historyID = null;
            string reportPath = "/AMRS/Interactive Features";
            ReportExecutionService rs = new ReportExecutionService();
            rs.Credentials = System.Net.CredentialCache.DefaultCredentials;
            rs.Url = "http://localhost/reportserver/ReportExecution2005.asmx";
            // Load the report for execution
            ExecutionInfo2 execInfo = rs.LoadReport2(reportPath, historyID);

            // Analyze the report configuration
            Console.WriteLine("SessionID: {0}", execInfo.ExecutionID);
            Console.WriteLine("Credentials Required: {0}", execInfo.CredentialsRequired);
            Console.WriteLine("Parameters Required: {0}", execInfo.ParametersRequired);

            foreach (ReportParameter p in execInfo.Parameters)
            {
                Console.WriteLine("Parameter Name: {0}, Default Value: {1}", p.Name, String.Join(",", p.DefaultValues == null ? new string[0] : p.DefaultValues));
            }

            // Prepare report parameters
            ParameterValue[] parameters = new ParameterValue[2];
            parameters[0] = new ParameterValue();
            parameters[0].Name = "Month";
            parameters[0].Value = "12";
            parameters[1] = new ParameterValue();
            parameters[1].Name = "Year";
            parameters[1].Value = "2003";
            rs.SetExecutionParameters2(parameters, null);

            // Render arguments
            string encoding;
            string mimeType;
            string extension;
            Warning[] warnings = null;
            string[] streamIDs = null;
            string format = "MHTML";
            string devInfo = null;
            byte[] result = null;
            
            try
            {
                result = rs.Render2(format, devInfo, PageCountMode.Estimate, out extension, out mimeType, out encoding, out warnings, out streamIDs);
                execInfo = rs.GetExecutionInfo2();
                Console.WriteLine("Execution date and time: {0}", execInfo.ExecutionDateTime);
                Console.WriteLine("Estimated number of pages: {0}", execInfo.NumPages);
            }
            catch (SoapException ex)
            {
                Console.WriteLine(ex.Detail.OuterXml);
            }
            // Write the contents of the report to an MHTML file.
            using (FileStream stream = File.Create("report.mhtml", result.Length))
            {
                Console.WriteLine("File created.");
                stream.Write(result, 0, result.Length);
                Console.WriteLine("Result written to the file.");
            }
        }
    }
}
