﻿using System;
using System.Net;
using System.Web;
using System.IO;
using System.IO.IsolatedStorage;
using System.Web.Services.Protocols;
using System.Web.UI.WebControls;
using System.Reflection;

namespace WebReporter
{
    /// <summary>
    /// Summary description for Util.
    /// </summary>
    public class Util
    {
        public static string SESSION_PARAMETERS = "parameters";
        public Util()
        {
            //
            // TODO: Add constructor logic here
            //
        }
        /// <summary>
        /// Gets the isolated storage stream where the user settings are persisted
        /// </summary>
        /// <param name="path">Path to the isolated storage</param>
        /// <param name="m">File Mode</param>
        /// <param name="a">File Access</param>
        /// <param name="s">File Share</param>
        /// <returns></returns>
        internal static Stream GetSettingsStream(string path, FileMode m, FileAccess a, FileShare s)
        {
            return new IsolatedStorageFileStream(path, m, a, s,
                IsolatedStorageFile.GetUserStoreForAssembly());
        }


        public static void ShowErrorMessage(string messageText, System.Exception ex, Label label)
        {
            if (ex != null)
            {
                if (ex is SoapException)
                {
                    switch (((SoapException)ex).Detail["ErrorCode"].InnerText)
                    {
                        case "rsReportParameterValueNotSet":
                            messageText += "\n" + "The report parameters do not match."; break;
                        case "rsItemNotFound":
                            messageText += "\n" + "Wrong report or report path. Please check the reportFolder element in the application configuration file."; break;
                    }
                    messageText += "\n" + "Exception Trace:\n" + ((SoapException)ex).Detail.InnerXml;
                }

                if (ex is System.Net.WebException)
                {
                    messageText += "\n" + "Cannot communicate with the Report Server. Please check the reportServer element in the application configuration file.";
                    messageText += "\n" + "Exception Trace:\n" + ex.ToString();
                }

            }
            label.Text = messageText;
        }
 

        internal static string CustomAuthCookieName
        {
            get
            {
                lock (m_cookieNamelockRoot)
                {
                    return m_cookieName;
                }
            }
            set
            {
                lock (m_cookieNamelockRoot)
                {
                    m_cookieName = value;
                }
            }
        }
        private static string m_cookieName = "sqlAuthCookie";
        private static object m_cookieNamelockRoot = new object();

        private static HttpCookie TranslateCookie(Cookie netCookie)
        {
            if (netCookie == null)
                return null;
            HttpCookie webCookie = new HttpCookie(netCookie.Name, netCookie.Value);
            // Add domain only if it is dotted - IE doesn't send back the cookie 
            // if we set the domain otherwise
            if (netCookie.Domain.IndexOf('.') != -1)
                webCookie.Domain = netCookie.Domain;
            webCookie.Expires = netCookie.Expires;
            webCookie.Path = netCookie.Path;
            webCookie.Secure = netCookie.Secure;
            return webCookie;
        }

        internal static Cookie TranslateCookie(HttpCookie webCookie)
        {
            if (webCookie == null)
                return null;
            Cookie netCookie = new Cookie(webCookie.Name, webCookie.Value);
            if (webCookie.Domain == null)
                netCookie.Domain =
                    HttpContext.Current.Request.ServerVariables["SERVER_NAME"];
            netCookie.Expires = webCookie.Expires;
            netCookie.Path = webCookie.Path;
            netCookie.Secure = webCookie.Secure;
            return netCookie;
        }

        internal static void RelayCookieToClient(Cookie cookie)
        {
            // add the cookie if not already in there
            if (HttpContext.Current.Response.Cookies[cookie.Name] == null)
            {
                HttpContext.Current.Response.Cookies.Remove(cookie.Name);
            }

            HttpContext.Current.Response.SetCookie(TranslateCookie(cookie));
        }

    }
}
