using System;
using System.Collections;
using System.ComponentModel;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Data;
using System.Windows.Forms;

namespace Prologika.RS.Extensibility.CRI
{

	/// <summary>
	/// ProgressTracker Control
	/// </summary>
    public class ProgressTracker: System.Windows.Forms.UserControl
	{
		//Class members
		private int				_alpha;
		private float			_max;
		private float			_min;
		private float			_value;
		private Color			_progressColor;
		private Color			_borderColor;
		private bool			_showValue;
        private Container       _components = null;
		/// <summary>
		/// ProgressTracker class
		/// </summary>
		public ProgressTracker() : base()
		{
			// This call is required by the Windows.Forms Form Designer.
			InitializeComponent();


		}

		#region Component Designer generated code
        /// <summary> 
        /// Clean up any resources being used.
        /// </summary>

        protected override void Dispose(bool disposing)
        {
            if (disposing)
            {
                if (_components != null)
                {
                    _components.Dispose();
                }
            }
            base.Dispose(disposing);
        }
		/// <summary> 
		/// Required method for Designer support 
		/// </summary>
		private void InitializeComponent()
		{
			// 
			// ProgressTracker
			// 
			this.ForeColor = System.Drawing.Color.LightGray;
			this.Name = "ProgressTracker";
			this.Size = new System.Drawing.Size(350, 80);
            this._min = -1;
            this._max = 1;
            this._value = 0.25F;
            this._progressColor = Color.Gold;
            this._alpha = 255;
            this._showValue = true;

		}
		#endregion

		#region Public Properties

		/// <summary>
		/// Inner color
		/// </summary>
		[Category("ProgressTracker"),
		DefaultValue(typeof(Color), "Gold")]
		public Color ProgressColor
		{
			get
			{
				return this._progressColor;
			}
			set
			{
				if ( this._progressColor != value )
				{
					this._progressColor = value;
					this.Invalidate();
				}
			}
		}

		/// <summary>
		/// Border color
		/// </summary>
		[Category("ProgressTracker"),
		DefaultValue(typeof(Color), "Gray")]
		public Color BorderColor
		{
			get
			{
				return this._borderColor;
			}
			set
			{
				if ( this._borderColor != value )
				{
					this._borderColor = value;
					this.Invalidate();
				}
			}
		}

		/// <summary>
		/// Maximum value
		/// </summary>
		[Category("ProgressTracker"),
		DefaultValue(1f)]
		public float Maximum
		{
			get
			{
				return this._max;
			}
			set
			{
				if ( this._max != value )
				{
					this._max = value;
				}
                
			}
		}

		/// <summary>
		/// Minimum value
		/// </summary>
		[Category("ProgressTracker"),
		DefaultValue(-1f)]
		public float Minimum
		{
			get
			{
				return this._min;
			}
			set
			{
				if ( this._min != value )
				{
					this._min = value;
                }
                
            }
		}

		/// <summary>
		/// Progress value
		/// </summary>
        [Category("ProgressTracker"), DefaultValue(0f), Description("The actual value.")]
		public float Value
		{
			get
			{
				return this._value ;
			}
			set
			{
				if ( this._value != value )
				{
                    if (value < this._min || value > this._max)
                        throw new ApplicationException("The progress value must be between the minimum and maximum values.");
					this._value = value;
                    this.Invalidate();
				}
			}
		}

		/// <summary>
		/// Customize the transparency
		/// </summary>
		[Category("ProgressTracker"),
		DefaultValue(255)]
		public int Alpha
		{
			get
			{
				return this._alpha;
			}
			set
			{
				if ( this._alpha != value )
				{
					this._alpha = value;
					this.Invalidate();
				}
			}
		}

		/// <summary>
		/// When True, displays the value text
		/// </summary>
		[Category("ProgressTracker"),
		DefaultValue(true)]
		public bool ShowValue
		{
			get
			{
				return this._showValue;
			}
			set
			{
				if ( this._showValue != value )
				{
					this._showValue = value;
					this.Invalidate();
				}
			}
		}
		#endregion

		#region Painting

		/// <summary>
		/// Overridden OnPaint for custom painting.
		/// </summary>
		/// <param name="e">A System.Windows.Forms.PaintEventArgs that contains the event data.</param>
		protected override void OnPaint(PaintEventArgs pe)
		{
			base.OnPaint(pe);
			Graphics g = pe.Graphics;
			g.SmoothingMode = SmoothingMode.AntiAlias;
            this.DrawControl(g, this.ForeColor);

		}//end Paint

		/// <summary>
		/// Do the actual drawing here
		/// </summary>
		/// <param name="g"></param>
		/// <param name="foreColor"></param>
		private void DrawControl(Graphics g, Color foreColor)
		{
			bool outLine = this._borderColor != Color.Transparent;
			Rectangle bar = this.ClientRectangle;

			bar.Inflate(-20, -20);
            DrawingUtils.DrawBar(g, bar, Color.FromArgb(this.Alpha, foreColor), this.BorderColor, outLine);

            if (this.Value >= this.Minimum && this.Value <= this.Maximum)
            {
                float value = bar.Width * ((this.Value - this.Minimum) / (this.Maximum - this.Minimum));
                Rectangle progress = Rectangle.FromLTRB(bar.Left, bar.Top, bar.Left + (int)value, bar.Bottom);

                DrawingUtils.DrawBar(g, progress, Color.FromArgb(this.Alpha, this.ProgressColor), this.BorderColor, outLine);

                // Draw the progress text inside the control
                if (this._showValue && progress.Height > 10)
                {
                    //g.SmoothingMode = SmoothingMode.AntiAlias;
                    StringFormat format = new StringFormat();
                    format.Alignment = StringAlignment.Center;
                    format.LineAlignment = StringAlignment.Center;
                    g.DrawString(this._value.ToString("F2"), this.Font, Brushes.Black, bar, format);
                    format.Dispose();
                }
            }
		}

		#endregion



	}
}
